# aipython

An enhanced Python shell with IPython-like features.

## Features

[x] **Autocompletion**
[x] **History**
[x] **Magic commands**

### Installation

```bash
pip install aipython
```

### Usage

```shell
$ aipython
```

## License

This project was distributed under the [MPL-2.0 License](LICENSE).
